@@ -2,4 +2,4 @@
 from highwire.events import Event, project
 from highwire.signals import Signal, LastEvent, Select
 from highwire.streams import Stream, AsyncStream
-from highwire.samplers import Sampler, MovingAverage
+from highwire.samplers import Sampler, MovingAverage, Tick
